STANNIX Solutions for the Real World


Manual: git-worktree

GIT-WORKTREE(1)					 Git Manual				     GIT-WORKTREE(1)

NAME
       git-worktree - Manage multiple working trees

SYNOPSIS
       git worktree add [-f] [--detach] [--checkout] [--lock [--reason ]]
			[--orphan] [(-b | -B) ]  []
       git worktree list [-v | --porcelain [-z]]
       git worktree lock [--reason ] 
       git worktree move  
       git worktree prune [-n] [-v] [--expire ]
       git worktree remove [-f] 
       git worktree repair [...]
       git worktree unlock 

DESCRIPTION
       Manage multiple working trees attached to the same repository.

       A git repository can support multiple working trees, allowing you to check out more than one branch
       at a time. With git worktree add a new working tree is associated with the repository, along with
       additional metadata that differentiates that working tree from others in the same repository. The
       working tree, along with this metadata, is called a "worktree".

       This new worktree is called a "linked worktree" as opposed to the "main worktree" prepared by git-
       init(1) or git-clone(1). A repository has one main worktree (if it’s not a bare repository) and zero
       or more linked worktrees. When you are done with a linked worktree, remove it with git worktree
       remove.

       In its simplest form, git worktree add  automatically creates a new branch whose name is the
       final component of , which is convenient if you plan to work on a new topic. For instance, git
       worktree add ../hotfix creates new branch hotfix and checks it out at path ../hotfix. To instead work
       on an existing branch in a new worktree, use git worktree add  . On the other hand, if
       you just plan to make some experimental changes or do testing without disturbing existing
       development, it is often convenient to create a throwaway worktree not associated with any branch.
       For instance, git worktree add -d  creates a new worktree with a detached HEAD at the same
       commit as the current branch.

       If a working tree is deleted without using git worktree remove, then its associated administrative
       files, which reside in the repository (see "DETAILS" below), will eventually be removed automatically
       (see gc.worktreePruneExpire in git-config(1)), or you can run git worktree prune in the main or any
       linked worktree to clean up any stale administrative files.

       If the working tree for a linked worktree is stored on a portable device or network share which is
       not always mounted, you can prevent its administrative files from being pruned by issuing the git
       worktree lock command, optionally specifying --reason to explain why the worktree is locked.

COMMANDS
       add  []
	   Create a worktree at  and checkout  into it. The new worktree is linked to the
	   current repository, sharing everything except per-worktree files such as HEAD, index, etc. As a
	   convenience,  may be a bare "-", which is synonymous with @{-1}.

	   If  is a branch name (call it ) and is not found, and neither -b nor -B nor
	   --detach are used, but there does exist a tracking branch in exactly one remote (call it
	   ) with a matching name, treat as equivalent to:

	       $ git worktree add --track -b   /

	   If the branch exists in multiple remotes and one of them is named by the checkout.defaultRemote
	   configuration variable, we’ll use that one for the purposes of disambiguation, even if the
	    isn’t unique across all remotes. Set it to e.g.  checkout.defaultRemote=origin to always
	   checkout remote branches from there if  is ambiguous but exists on the origin remote. See
	   also checkout.defaultRemote in git-config(1).

	   If  is omitted and neither -b nor -B nor --detach used, then, as a convenience, the
	   new worktree is associated with a branch (call it ) named after $(basename ). If
	    doesn’t exist, a new branch based on HEAD is automatically created as if -b  was
	   given. If  does exist, it will be checked out in the new worktree, if it’s not checked
	   out anywhere else, otherwise the command will refuse to create the worktree (unless --force is
	   used).

	   If  is omitted, neither --detach, or --orphan is used, and there are no valid local
	   branches (or remote branches if --guess-remote is specified) then, as a convenience, the new
	   worktree is associated with a new unborn branch named  (after $(basename ) if
	   neither -b or -B is used) as if --orphan was passed to the command. In the event the repository
	   has a remote and --guess-remote is used, but no remote or local branches exist, then the command
	   fails with a warning reminding the user to fetch from their remote first (or override by using
	   -f/--force).

       list
	   List details of each worktree. The main worktree is listed first, followed by each of the linked
	   worktrees. The output details include whether the worktree is bare, the revision currently
	   checked out, the branch currently checked out (or "detached HEAD" if none), "locked" if the
	   worktree is locked, "prunable" if the worktree can be pruned by the prune command.

       lock
	   If a worktree is on a portable device or network share which is not always mounted, lock it to
	   prevent its administrative files from being pruned automatically. This also prevents it from
	   being moved or deleted. Optionally, specify a reason for the lock with --reason.

       move
	   Move a worktree to a new location. Note that the main worktree or linked worktrees containing
	   submodules cannot be moved with this command. (The git worktree repair command, however, can
	   reestablish the connection with linked worktrees if you move the main worktree manually.)

       prune
	   Prune worktree information in $GIT_DIR/worktrees.

       remove
	   Remove a worktree. Only clean worktrees (no untracked files and no modification in tracked files)
	   can be removed. Unclean worktrees or ones with submodules can be removed with --force. The main
	   worktree cannot be removed.

       repair [...]
	   Repair worktree administrative files, if possible, if they have become corrupted or outdated due
	   to external factors.

	   For instance, if the main worktree (or bare repository) is moved, linked worktrees will be unable
	   to locate it. Running repair in the main worktree will reestablish the connection from linked
	   worktrees back to the main worktree.

	   Similarly, if the working tree for a linked worktree is moved without using git worktree move,
	   the main worktree (or bare repository) will be unable to locate it. Running repair within the
	   recently-moved worktree will reestablish the connection. If multiple linked worktrees are moved,
	   running repair from any worktree with each tree’s new  as an argument, will reestablish the
	   connection to all the specified paths.

	   If both the main worktree and linked worktrees have been moved or copied manually, then running
	   repair in the main worktree and specifying the new  of each linked worktree will
	   reestablish all connections in both directions.

       unlock
	   Unlock a worktree, allowing it to be pruned, moved or deleted.

OPTIONS
       -f, --force
	   By default, add refuses to create a new worktree when  is a branch name and is
	   already checked out by another worktree, or if  is already assigned to some worktree but is
	   missing (for instance, if  was deleted manually). This option overrides these safeguards.
	   To add a missing but locked worktree path, specify --force twice.

	   move refuses to move a locked worktree unless --force is specified twice. If the destination is
	   already assigned to some other worktree but is missing (for instance, if  was deleted
	   manually), then --force allows the move to proceed; use --force twice if the destination is
	   locked.

	   remove refuses to remove an unclean worktree unless --force is used. To remove a locked worktree,
	   specify --force twice.

       -b , -B 
	   With add, create a new branch named  starting at , and check out
	    into the new worktree. If  is omitted, it defaults to HEAD. By default,
	   -b refuses to create a new branch if it already exists.  -B overrides this safeguard, resetting
	    to .

       -d, --detach
	   With add, detach HEAD in the new worktree. See "DETACHED HEAD" in git-checkout(1).

       --checkout, --no-checkout
	   By default, add checks out , however, --no-checkout can be used to suppress checkout
	   in order to make customizations, such as configuring sparse-checkout. See "Sparse checkout" in
	   git-read-tree(1).

       --guess-remote, --no-guess-remote
	   With worktree add , without , instead of creating a new branch from HEAD, if
	   there exists a tracking branch in exactly one remote matching the basename of , base the
	   new branch on the remote-tracking branch, and mark the remote-tracking branch as "upstream" from
	   the new branch.

	   This can also be set up as the default behaviour by using the worktree.guessRemote config option.

       --relative-paths, --no-relative-paths
	   Link worktrees using relative paths or absolute paths (default). Overrides the
	   worktree.useRelativePaths config option, see git-config(1).

	   With repair, the linking files will be updated if there’s an absolute/relative mismatch, even if
	   the links are correct.

       --track, --no-track
	   When creating a new branch, if  is a branch, mark it as "upstream" from the new
	   branch. This is the default if  is a remote-tracking branch. See --track in git-
	   branch(1) for details.

       --lock
	   Keep the worktree locked after creation. This is the equivalent of git worktree lock after git
	   worktree add, but without a race condition.

       -n, --dry-run
	   With prune, do not remove anything; just report what it would remove.

       --orphan
	   With add, make the new worktree and index empty, associating the worktree with a new unborn
	   branch named .

       --porcelain
	   With list, output in an easy-to-parse format for scripts. This format will remain stable across
	   Git versions and regardless of user configuration. It is recommended to combine this with -z. See
	   below for details.

       -z
	   Terminate each line with a NUL rather than a newline when --porcelain is specified with list.
	   This makes it possible to parse the output when a worktree path contains a newline character.

       -q, --quiet
	   With add, suppress feedback messages.

       -v, --verbose
	   With prune, report all removals.

	   With list, output additional information about worktrees (see below).

       --expire